Skráning | OiRA

Þemu

# Skráning

## Af hverju þarf ég að skrá mig?

Það fyrsta, sem þú verður beðin/n um þegar þú byrjar fyrsta áhættumatið þitt, er að búa til OiRA aðgang - en það er einfalt og fljótlegt.

Skráningin gerir þér kleift að skrá þig inn hvenær sem er til að fá aðgang að upplýsingunum þínum, halda áfram með fyrri möt eða byrja ný.

Skráningin þýðir að OiRA-kerfið getur vistað allar setur þínar og upplýsingarnar þínar eru alltaf tiltækar.

Lestu friðhelgisstefnuna okkar og fáðu upplýsingar um hvernig við meðhöndlum persónuupplýsingar.

## Hver er munurinn á notandaskráningu og prufuaðgangi?

Prufuaðgangurinn gerir áhugasömum kleift að skoða verkfærið áður en þeir taka ákvörðun um skráningu. En við prufuaðgang eru upplýsingarnar þínar ekki vistaðar, þú getur ekki sótt neinar upplýsingar, sem þú hefur skráð, á síðari stigum. V prufuaðgang getur þú ekki prentað út neinar skýrslur en ef þú stofnar aðgang getur þú skrásett áhættumatið þitt fullkomlega.

## Stofnun á nýjum aðgangi

Er þetta fyrsta heimsóknin þín? Fylgdu þessum einföldu skrefum til að hefjast handa:

1.) Smelltu á „stofna aðgang“ til að sjá skráningareyðublaðið.

Skráningareyðublað.

2.) Færðu inn netfang og veldu þér aðgangsorð (tvisvar)

3.) Smelltu á „áfram“ til að stofna nýja aðganginn þinn.

4.) Lestu og samþykktu friðhelgisstefnuna til að halda áfram

Nú ertu skráð/ur inn í OiRA-kerfið.

## Innskráning á aðgang sem hefur verið stofnaður

Ef þú ert búin/n að stofna aðgang skráir þú þig inn með eftirfarandi hætti:

1.) Farðu á innskráningareyðublaðið. Hlekkur á innskráningareyðublaðið birtist í hvert sinn sem þú reynir að fara á OiRA þangað til þú hefur skráð þig inn.

Innskráningareyðublað.

2.) Færðu inn netfangið þitt og aðgangsorð.

3.) Skráðu þig inn með því að smella á hnappinn „innskráning“.

Þegar þú hefur innskráð þig sérðu skjámyndina fyrir neðan. Þaðan getur þú byrjað nýtt áhættumat eða farið á fyrri áhættumöt sem þú hefur áður byrjað á.

Stjórnborðið.

Byrjaðu nýtt áhættumat með því að gefa því heiti (t.d. Fyrirtækið mitt 03. 07. 2018) eða veldu eitt af fyrri áhættumötunum sem þú hefur gert. Öll áhættumötin þín eru vistuð til að skoða síðar nema ef þú veljir að eyðir þeim.

Scroll to top Load toolbar…
Back

## 1-registration.md

Meira

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More